@@ -1,6 +1,12 @@
+from __future__ import annotations
+from typing import Final
+
 from .base import *
 from .constants import *
 from .decorators import *
 from .input import *
 from .process import *
 from .types import *
+
+
+NAME: Final[str] = 'strs'
